using System;
using System.Windows.Forms;
using System.Text;
namespace PHS
{
    public partial class SelectionForm : Form
    {
        public string VariableName; // This contains the most recently entered variable name.
        public bool Cancelled = false; // This is set to true if the Cancel button was pressed.
        const string DefaultVariableName = "MyMacAddresses"; // This is the default variable name we assume if we're not give one.
        const string Title = "MAC addresses plugin."; // The title used in message boxes.

        public SelectionForm(string variableName)
        {
            InitializeComponent();
            VariableName = variableName;
        }

        private void OkButtonClick(object sender, EventArgs e)
        {
            VariableName = VariableTextBox.Text.Trim();
            if(string.IsNullOrEmpty(VariableName))
            {
                VariableName = DefaultVariableName;
                StringBuilder sb = new StringBuilder();
                sb.AppendLine("You have not defined a variable for the plugin statement to return the selected MAC addresses into.");
                sb.AppendLine();
                sb.AppendLine(string.Format("A default variable called '{0}' will be used instead.", DefaultVariableName));
                sb.AppendLine();
                sb.AppendLine("Don't forget to create this variable with the Set Variable statement before the plugin statement in the MSIcode window.");
                MessageBox.Show(sb.ToString(), Title, MessageBoxButtons.OK, MessageBoxIcon.Information);
            }
            Close();
        }

        private void SelectionLoad(object sender, EventArgs e)
        {
            // The constructor was given a selected item and a variable name. The variable name can be displayed in the textbox as is. The
            // selected item however, contains the text of the item in the combobox. Loop through the items and search for the one that's
            // the same as the one we're interested in. The index where we find it is used to preposition the combobox to the same item.

            VariableTextBox.Text = VariableName;
        }

        private void CancelButtonClick(object sender, EventArgs e)
        {
            Cancelled = true;
            Close();
        }

        private void HelpButtonClick(object sender, EventArgs e)
        {
            StringBuilder sb = new StringBuilder();
            sb.AppendLine("This plugin gets all MAC addresses from the current machine for controllers which are up and running.");
            sb.AppendLine();
            sb.Append("Enter the variable name you want the values to be returned into. If you don't enter a variable name a default will be assigned for you. ");
            sb.AppendLine("You can change the variable name at anytime.");
            sb.AppendLine();
            sb.AppendLine("Created by Peter Hamilton-Scott (December 2014)");
            MessageBox.Show(sb.ToString(), Title, MessageBoxButtons.OK, MessageBoxIcon.Information);
        }
    }
}
